/**
 * 获取文件后缀
 * @param path 文件名
 */
export declare function isGif(path: string): boolean;
/**
 * 配置信息
 */
export declare const config: {
    /**
     * 宽度, 默认2K屏
     */
    Width: number;
    /**
     * 屏幕高度, 默认2K屏幕
     */
    Height: number;
    /**
     * 图片质量1~100
     */
    Quality: number;
    /**
     * 缩略图宽度
     */
    ThumbnailWidth: number;
    /**
     * 缩略图宽度1~100
     */
    ThumbnailQuality: number;
    /**
     * 代替换的域名列表
     */
    DomainList: (string | RegExp)[];
    /**
     * 图片处理CDN
     */
    ImageCDN: string;
    /**
     * 媒体流加速CDN
     */
    StreamCDN: string;
    isAndroid: boolean;
};
/**
 * 生成压缩URL
 * 非http/https资源不处理
 * @param option 压缩参数
 * @param cdnSite CDN域名 如 `https://mycdn.net/` 空则不替换
 * @param domainList 域名列表 `[/^https?:\/\/[\w\-\.]*\//]`
 */
export declare function compress(option: CDNOptions, cdnSite?: string, domainList?: Array<string | RegExp>): string;
/**
 * 屏幕宽度自适应图像
 * @param url url of image
 */
export declare function adaptiveImage(url: string): string;
/**
 * 横屏自适应图像
 * @param url url of image
 */
export declare function adaptiveLandscapeImage(url: string): string;
/**
 * 渐进式加载大图
 * @param url image URL
 */
export declare function progressiveImage(url: string): string;
/**
 * 生成好友对话消息的缩略图
 * @param url image Url
 */
export declare function shareImage(url: string): string;
/**
 * 小尺寸缩略图
 * @param url 原url
 */
export declare function thumbnail(url: string): string;
/**
 * 流媒体
 * @param url 原url
 */
export declare function streamCdn(url: string): string;
/**
 * 压缩头像
 * @param url
 * @param size
 */
export declare function compressAvatar(url: string, size: 0 | 46 | 64 | 96 | 132): string;
/**
 * CDN 压缩参数
 */
export interface CDNOptions {
    /**
     * 原始URL
     */
    url: string;
    /**
     * 0 或 不定义	锁定宽高比且长边优先
    1	锁定宽高比且短边优先
    2	强制宽高
    4	锁定宽高比且短边优先，并在缩放后以指定颜色填充空白区域（若颜色未指定则自动采用白色填充
     */
    scaleType?: 0 | 1 | 2 | 4;
    /**
     * 值为 0 或 1 的整数，默认为 0 即不进行其他操作，为1则自动裁剪原图至指定尺寸
     */
    cut?: boolean;
    /**
     * 输出宽度
     */
    width?: number;
    /**
     * 输出高度
     */
    height?: number;
    /**
     * 图片质量默认100
     */
    quality?: number;
    /**
     * 是否渐进加载
     */
    progressive?: boolean;
    /**
     * 图片是否放大
     * 默认值为false，
     * 为 `true` 即允许将图片缩放至大于原图的尺寸，
     */
    larger?: boolean;
    /**
     * 输出格式
     */
    ext?: ".jpg" | ".webp" | ".png" | ".jpeg" | ".gif";
    /**
     * 处理失败是否返回原图
     */
    acceptraw?: boolean;
}
//# sourceMappingURL=index.d.ts.map