"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var COMPRESS_PREFIX = /*#__PURE__*/ "?basic=";
/**
 * 获取文件后缀
 * @param path 文件名
 */
function isGif(path) {
    return path && path.toLowerCase().substring(path.length - 4, path.length) === ".gif";
}
exports.isGif = isGif;
/**
 * URL预处理
 */
function replaceUrl(url, domainList, cdnSite) {
    if (typeof url !== "string") {
        (console.error || console.log)("[cdn]invalid url:", url);
    }
    else {
        url = url.split(COMPRESS_PREFIX)[0];
        domainList.forEach(function (e) { return (url = url.replace(e, cdnSite)); });
    }
    return url;
}
/**
 * 配置信息
 */
exports.config = {
    /**
     * 宽度, 默认2K屏
     */
    Width: 1440,
    /**
     * 屏幕高度, 默认2K屏幕
     */
    Height: 2560,
    /**
     * 图片质量1~100
     */
    Quality: 100,
    /**
     * 缩略图宽度
     */
    ThumbnailWidth: 138,
    /**
     * 缩略图宽度1~100
     */
    ThumbnailQuality: 1,
    /**
     * 代替换的域名列表
     */
    DomainList: [],
    /**
     * 图片处理CDN
     */
    ImageCDN: "",
    /**
     * 媒体流加速CDN
     */
    StreamCDN: "",
    isAndroid: false,
};
/**
 * 生成压缩URL
 * 非http/https资源不处理
 * @param option 压缩参数
 * @param cdnSite CDN域名 如 `https://mycdn.net/` 空则不替换
 * @param domainList 域名列表 `[/^https?:\/\/[\w\-\.]*\//]`
 */
function compress(option, cdnSite, domainList) {
    if (domainList === void 0) { domainList = []; }
    if (option.url.indexOf('http') !== 0) {
        return option.url;
    }
    var url = cdnSite ? replaceUrl(option.url, domainList, cdnSite) : option.url;
    var param = "";
    if (option.width) {
        param += "_" + option.width + "w";
    }
    if (option.height) {
        param += "_" + option.height + "h";
    }
    if (option.quality && option.quality < 100) {
        param += "_" + option.quality + "q";
    }
    if (option.progressive) {
        param += "_1pr";
    }
    if (option.scaleType) {
        param += "_" + option.scaleType + "e";
    }
    if (option.cut) {
        param += "_1c";
    }
    if (option.ext) {
        param += option.ext;
    }
    return param ? url + COMPRESS_PREFIX + (option.larger ? "0l" : "1l") + param + (option.acceptraw ? '&p=acceptraw' : '') : url;
}
exports.compress = compress;
/**
 * 屏幕宽度自适应图像
 * @param url url of image
 */
function adaptiveImage(url) {
    return isGif(url)
        ? url // gif 不处理
        : compress({
            acceptraw: true,
            url: url,
            width: exports.config.Width,
            quality: exports.config.Quality,
            progressive: exports.config.Width > 800,
            ext: exports.config.isAndroid ? ".webp" : ".jpg",
        }, exports.config.ImageCDN, exports.config.DomainList);
}
exports.adaptiveImage = adaptiveImage;
/**
 * 横屏自适应图像
 * @param url url of image
 */
function adaptiveLandscapeImage(url) {
    var width = exports.config.Width > exports.config.Height ? exports.config.Width : exports.config.Height;
    return isGif(url)
        ? url // gif 不处理
        : compress({
            acceptraw: true,
            url: url,
            width: width,
            quality: exports.config.Quality,
            progressive: width > 800,
            ext: exports.config.isAndroid ? ".webp" : ".jpg",
        }, exports.config.ImageCDN, exports.config.DomainList);
}
exports.adaptiveLandscapeImage = adaptiveLandscapeImage;
/**
 * 渐进式加载大图
 * @param url image URL
 */
function progressiveImage(url) {
    return isGif(url)
        ? url // gif 不处理
        : compress({
            acceptraw: true,
            url: url,
            progressive: true,
            ext: exports.config.isAndroid ? ".webp" : ".jpg",
        }, exports.config.ImageCDN, exports.config.DomainList);
}
exports.progressiveImage = progressiveImage;
/**
 * 生成好友对话消息的缩略图
 * @param url image Url
 */
function shareImage(url) {
    return isGif(url)
        ? url
        : compress({
            acceptraw: true,
            url: url,
            width: 500,
            height: 400,
            cut: true,
            scaleType: 1,
            quality: 75,
            larger: true,
            ext: ".jpg",
        }, exports.config.ImageCDN, exports.config.DomainList);
}
exports.shareImage = shareImage;
/**
 * 小尺寸缩略图
 * @param url 原url
 */
function thumbnail(url) {
    return compress({
        acceptraw: true,
        url: url,
        width: exports.config.ThumbnailWidth,
        quality: exports.config.ThumbnailQuality,
        ext: ".jpg",
    }, exports.config.ImageCDN, exports.config.DomainList);
}
exports.thumbnail = thumbnail;
/**
 * 流媒体
 * @param url 原url
 */
function streamCdn(url) {
    return exports.config.StreamCDN ? replaceUrl(url, exports.config.DomainList, exports.config.StreamCDN) : url;
}
exports.streamCdn = streamCdn;
/**
 * 压缩头像
 * @param url
 * @param size
 */
function compressAvatar(url, size) {
    if (url.indexOf("https://wx.qlogo.cn") === 0) {
        return url.substring(0, url.lastIndexOf("/") + 1) + size;
    }
    return isGif(url)
        ? url
        : compress(size > 0
            ? {
                url: url,
                width: size,
                height: size,
                cut: true,
                scaleType: 1,
                ext: ".jpg",
                acceptraw: true,
            }
            : {
                url: url,
                ext: ".jpg",
                acceptraw: true,
            }, exports.config.ImageCDN, exports.config.DomainList);
}
exports.compressAvatar = compressAvatar;
